# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.gaming.input.custom

Self = typing.TypeVar('Self')

class GameControllerProviderInfo_Static(type):
    def get_parent_provider_id(cls, provider: typing.Optional[winrt.windows.gaming.input.custom.IGameControllerProvider], /) -> str: ...
    def get_provider_id(cls, provider: typing.Optional[winrt.windows.gaming.input.custom.IGameControllerProvider], /) -> str: ...

class GameControllerProviderInfo(winrt.system.Object, metaclass=GameControllerProviderInfo_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GameControllerProviderInfo: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import winrt.system
from winrt import _winrt_windows_gaming_input_preview

__all__ = [
    "GameControllerProviderInfo",
]

GameControllerProviderInfo = _winrt_windows_gaming_input_preview.GameControllerProviderInfo
